@@ -99,6 +99,13 @@ $(document).ready(function () {
         console.log(audio.duration);
     });
     */
+		stopVisualiseAudio();
+
+        if (!spectrumAnalyserActive) {
+            analyserRandom = Math.round(Math.random() * 1 + 1);
+            visualiseAudio(null);
+            spectrumAnalyserActive = true;
+        }
         audio.load();
         audio.play;
         // setTimeout(() => {
@@ -272,13 +279,6 @@ $(document).ready(function () {
                 console.log('activate_audio');
                 stopVisualiseAudio();
 
-                try {
-                    analyser = audioContext.createAnalyser();
-                    audioSource.connect(analyser);
-                    analyser.connect(audioContext.destination);
-                } catch (error) {
-                    console.error(error);
-                };
                 audio.volume = 0.25;
                 audio_volume_control.value = 25;
                 audio.src = "";
@@ -289,7 +289,8 @@ $(document).ready(function () {
                 audio.play();
 
                 if (!spectrumAnalyserActive) {
-                    analyserRandom = getRandomIntInclusive(1,2);
+                    analyserRandom = Math.round(Math.random() * 1 + 1);
+                    //  analyserRandom = getRandomIntInclusive(1,2);
                     visualiseAudio(null);
                     spectrumAnalyserActive = true;
                 }
@@ -395,7 +396,9 @@ $(document).ready(function () {
     ;
 
     function stopVisualiseAudio() {
-       window.cancelAnimationFrame(requestIdAnimationFrame);
+       try {
+            window.cancelAnimationFrame(requestIdAnimationFrame);
+       } catch (error) {console.error(error);}
        requestIdAnimationFrame = undefined;
        spectrumAnalyserActive = false;
     }
