@@ -1,5 +1,4 @@
 import os
-import queue
 
 from flask import Blueprint, render_template, request, url_for, flash, redirect, make_response, jsonify, Response
 
@@ -7,13 +6,10 @@ import eisenradio.lib.ghetto_recorder as ghetto
 from eisenradio.eisenutil.browser_stream import stream_audio_feed, get_stream_content_type
 from eisenradio.eisenutil.eisutil import make_folder, is_in_db_view, remove_blank
 from eisenradio.eisenutil.measure import measure_meta, stopped_stations
-from eisenradio.eisenutil.tools import delete_all_radios, export_radios, import_radios
+from eisenradio.eisenutil.tools import delete_all_radios, export_radios, import_radios, radio_spare_image
 from eisenradio.lib.eisdb import get_db_connection, status_read_status_set, render_picture, get_download_dir, \
     get_post, get_db_path
 
-local_play_queue = queue.Queue()    # no maxsize
-local_playlist_ext = ''
-
 # Blueprint Configuration
 eisenutil_bp = Blueprint(
     'eisenutil_bp', __name__,
@@ -83,11 +79,14 @@ def about():
 
 @eisenutil_bp.route('/create', methods=('GET', 'POST'))
 def create():
+
     if request.method == 'POST':
         rv_req = request.form['title']
         title = remove_blank(rv_req)
         name_in_db = is_in_db_view(title)
         content = request.form['content']
+        radio_image = None
+        content_type = None
 
         if not title:
             flash('Name is required!', 'warning')
@@ -106,15 +105,15 @@ def create():
             print(f' name {file.name} content-type {file.content_type}')
             try:
                 db_img = file.read()
-                image = render_picture(db_img, 'encode')
+                radio_image = render_picture(db_img, 'encode')
             except Exception as e:
                 print(e)
-                image = None
+                radio_image = None
                 content_type = None
-                pass
+
         else:
-            image = None
-            content_type = None
+            if not name_in_db:
+                radio_image, content_type = radio_spare_image()
 
         if request.form['text']:
             text = request.form['text']
@@ -134,7 +133,7 @@ def create():
         else:
             conn.execute('INSERT INTO posts (title, content, download_path, pic_data, pic_content_type, pic_comment) '
                          'VALUES (?, ?, ?, ?, ?, ?)',
-                         (title, content, request_path, image, content_type, text))
+                         (title, content, request_path, radio_image, content_type, text))
 
         conn.commit()
         conn.close()
@@ -292,17 +291,3 @@ def sound(radio_name):
     response.headers['Cache-Control'] = 'no-store'
     response.headers['Access-Control-Allow-Origin'] = '*'
     return response
-
-
-
-
-
-
-
-
-
-
-
-
-
-
